@@ -217,7 +217,7 @@ async def _handle_conversation_turn(
 
     start_time = time.monotonic()
 
-    if provider_cfg.llm_provider == "local":
+    if provider_cfg.llm_provider == "ollama":
         model_name = ollama_cfg.llm_ollama_model
     elif provider_cfg.llm_provider == "openai":
         model_name = openai_llm_cfg.llm_openai_model
@@ -383,6 +383,8 @@ def chat(
     asr_wyoming_ip: str = opts.ASR_WYOMING_IP,
     asr_wyoming_port: int = opts.ASR_WYOMING_PORT,
     asr_openai_model: str = opts.ASR_OPENAI_MODEL,
+    asr_openai_base_url: str | None = opts.ASR_OPENAI_BASE_URL,
+    asr_openai_prompt: str | None = opts.ASR_OPENAI_PROMPT,
     # --- LLM Configuration ---
     llm_ollama_model: str = opts.LLM_OLLAMA_MODEL,
     llm_ollama_host: str = opts.LLM_OLLAMA_HOST,
@@ -403,6 +405,7 @@ def chat(
     tts_wyoming_speaker: str | None = opts.TTS_WYOMING_SPEAKER,
     tts_openai_model: str = opts.TTS_OPENAI_MODEL,
     tts_openai_voice: str = opts.TTS_OPENAI_VOICE,
+    tts_openai_base_url: str | None = opts.TTS_OPENAI_BASE_URL,
     tts_kokoro_model: str = opts.TTS_KOKORO_MODEL,
     tts_kokoro_voice: str = opts.TTS_KOKORO_VOICE,
     tts_kokoro_host: str = opts.TTS_KOKORO_HOST,
@@ -473,6 +476,8 @@ def chat(
         openai_asr_cfg = config.OpenAIASR(
             asr_openai_model=asr_openai_model,
             openai_api_key=openai_api_key,
+            openai_base_url=asr_openai_base_url,
+            asr_openai_prompt=asr_openai_prompt,
         )
         ollama_cfg = config.Ollama(
             llm_ollama_model=llm_ollama_model,
@@ -504,6 +509,7 @@ def chat(
             tts_openai_model=tts_openai_model,
             tts_openai_voice=tts_openai_voice,
             openai_api_key=openai_api_key,
+            tts_openai_base_url=tts_openai_base_url,
         )
         kokoro_tts_cfg = config.KokoroTTS(
             tts_kokoro_model=tts_kokoro_model,
