@@ -98,6 +98,7 @@ def speak(
     # OpenAI
     tts_openai_model: str = opts.TTS_OPENAI_MODEL,
     tts_openai_voice: str = opts.TTS_OPENAI_VOICE,
+    tts_openai_base_url: str | None = opts.TTS_OPENAI_BASE_URL,
     # Kokoro
     tts_kokoro_model: str = opts.TTS_KOKORO_MODEL,
     tts_kokoro_voice: str = opts.TTS_KOKORO_VOICE,
@@ -140,8 +141,8 @@ def speak(
     with process.pid_file_context(process_name), suppress(KeyboardInterrupt):
         provider_cfg = config.ProviderSelection(
             tts_provider=tts_provider,
-            asr_provider="local",  # Not used
-            llm_provider="local",  # Not used
+            asr_provider="wyoming",  # Not used
+            llm_provider="ollama",  # Not used
         )
         audio_out_cfg = config.AudioOutput(
             output_device_index=output_device_index,
@@ -159,6 +160,7 @@ def speak(
         openai_tts_cfg = config.OpenAITTS(
             tts_openai_model=tts_openai_model,
             tts_openai_voice=tts_openai_voice,
+            tts_openai_base_url=tts_openai_base_url,
         )
         kokoro_tts_cfg = config.KokoroTTS(
             tts_kokoro_model=tts_kokoro_model,
