@@ -8,9 +8,9 @@ import logging
 import platform
 import time
 from contextlib import suppress
-from datetime import UTC, datetime
+from datetime import UTC, datetime, timedelta
 from pathlib import Path  # noqa: TC003
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 import pyperclip
 import typer
@@ -20,7 +20,10 @@ from agent_cli.cli import app
 from agent_cli.core import process
 from agent_cli.core.audio import pyaudio_context, setup_devices
 from agent_cli.core.utils import (
+    format_short_timedelta,
+    iter_lines_from_file_end,
     maybe_live,
+    parse_json_line,
     print_command_line_args,
     print_input_panel,
     print_output_panel,
@@ -88,6 +91,129 @@ INSTRUCTION = """
 Please clean up this transcribed text by correcting any speech recognition errors, adding appropriate punctuation and capitalization, removing obvious filler words or false starts, and improving overall readability while preserving the original meaning and intent of the speaker.
 """
 
+RECENT_CONTEXT_LOOKBACK_SECONDS = 60 * 60  # 1 hour
+RECENT_CONTEXT_MAX_ENTRIES = 3
+RECENT_CONTEXT_MAX_CHARS = 500
+RECENT_CONTEXT_READ_CHUNK_BYTES = 4096
+CLIPBOARD_CONTEXT_MAX_CHARS = 500
+
+
+def _build_context_line(
+    entry: dict[str, Any],
+    *,
+    now: datetime,
+    cutoff: datetime,
+    max_chars_per_entry: int,
+) -> tuple[str | None, bool]:
+    timestamp_str = entry.get("timestamp")
+    if not timestamp_str:
+        return None, False
+
+    try:
+        entry_ts = datetime.fromisoformat(timestamp_str)
+    except ValueError:
+        return None, False
+
+    if entry_ts < cutoff:
+        return None, True
+
+    # Both the CLI (`raw_output`/`processed_output`) and API (`raw`/`processed`)
+    # logging formats are supported, preferring the raw transcript when present.
+    text = (entry.get("raw_output") or entry.get("raw") or "").strip()
+    if not text:
+        return None, False
+
+    if max_chars_per_entry > 0 and len(text) > max_chars_per_entry:
+        text = text[:max_chars_per_entry].rstrip() + "..."
+
+    delta_str = format_short_timedelta(now - entry_ts)
+    return f"- {delta_str} ago (raw transcript): {text}", False
+
+
+def _gather_recent_transcription_context(
+    log_file: Path,
+    *,
+    max_age_seconds: int = RECENT_CONTEXT_LOOKBACK_SECONDS,
+    max_entries: int = RECENT_CONTEXT_MAX_ENTRIES,
+    max_chars_per_entry: int = RECENT_CONTEXT_MAX_CHARS,
+    now: datetime | None = None,
+    chunk_size: int = RECENT_CONTEXT_READ_CHUNK_BYTES,
+) -> str | None:
+    """Return recent transcription snippets to give the LLM additional context."""
+    if max_entries <= 0 or max_age_seconds <= 0:
+        return None
+    if not log_file.exists():
+        return None
+    if chunk_size <= 0:
+        chunk_size = RECENT_CONTEXT_READ_CHUNK_BYTES
+
+    now = now or datetime.now(UTC)
+    cutoff = now - timedelta(seconds=max_age_seconds)
+    context_entries: list[str] = []
+
+    try:
+        for line in iter_lines_from_file_end(log_file, chunk_size):
+            entry = parse_json_line(line)
+            if not entry:
+                continue
+            context_line, should_stop = _build_context_line(
+                entry,
+                now=now,
+                cutoff=cutoff,
+                max_chars_per_entry=max_chars_per_entry,
+            )
+            if should_stop:
+                break
+            if context_line:
+                context_entries.append(context_line)
+                if len(context_entries) >= max_entries:
+                    break
+    except OSError as exc:
+        LOGGER.debug("Unable to read transcription log %s: %s", log_file, exc)
+        return None
+
+    if not context_entries:
+        return None
+
+    history_lines = "\n".join(reversed(context_entries))
+    header = "Recent transcript history (time deltas relative to now):\n"
+    return header + history_lines
+
+
+def _build_context_payload(
+    *,
+    transcription_log: Path | None,
+    clipboard_snapshot: str | None,
+) -> tuple[str | None, str | None]:
+    """Return combined context text and the note to append to instructions."""
+    context_sections: list[str] = []
+
+    if transcription_log:
+        log_context = _gather_recent_transcription_context(transcription_log)
+        if log_context:
+            context_sections.append(log_context)
+
+    if clipboard_snapshot:
+        clipboard_text = clipboard_snapshot.strip()
+        if clipboard_text:
+            if len(clipboard_text) > CLIPBOARD_CONTEXT_MAX_CHARS:
+                clipboard_text = clipboard_text[:CLIPBOARD_CONTEXT_MAX_CHARS].rstrip() + "..."
+            context_sections.append(
+                "Clipboard content captured before this recording "
+                "(truncated for safety; may be unrelated to the new request):\n"
+                f"- {clipboard_text}",
+            )
+
+    if not context_sections:
+        return None, None
+
+    combined_context = "\n\n".join(context_sections)
+    instructions_note = (
+        "\n\n<context> contains recent log transcripts and/or clipboard text. "
+        "Treat it as optional background and clean only the text inside <original-text>."
+    )
+    return combined_context, instructions_note
+
 
 def log_transcription(
     log_file: Path,
@@ -111,7 +237,7 @@ def log_transcription(
         f.write(json.dumps(log_entry) + "\n")
 
 
-async def _async_main(  # noqa: PLR0912, PLR0915
+async def _async_main(  # noqa: PLR0912, PLR0915, C901
     *,
     extra_instructions: str | None,
     provider_cfg: config.ProviderSelection,
@@ -146,9 +272,11 @@ async def _async_main(  # noqa: PLR0912, PLR0915
 
             recorded_transcriber = create_recorded_audio_transcriber(provider_cfg)
 
-            asr_config = (
-                openai_asr_cfg if provider_cfg.asr_provider == "openai" else wyoming_asr_cfg
-            )
+            if provider_cfg.asr_provider == "openai":
+                asr_config = openai_asr_cfg
+            else:
+                asr_config = wyoming_asr_cfg
+
             # Call with appropriate arguments based on provider
             if provider_cfg.asr_provider == "openai":
                 transcript = await recorded_transcriber(
@@ -195,12 +323,24 @@ async def _async_main(  # noqa: PLR0912, PLR0915
                     title="📝 Raw Transcript",
                     subtitle=f"[dim]took {elapsed:.2f}s[/dim]",
                 )
+            clipboard_snapshot: str | None = None
+            if general_cfg.clipboard:
+                clipboard_snapshot = pyperclip.paste()
+                pyperclip.copy(transcript)
+                LOGGER.info("Copied raw transcript to clipboard before LLM processing.")
             instructions = AGENT_INSTRUCTIONS
             if extra_instructions:
                 instructions += f"\n\n{extra_instructions}"
 
+            combined_context, context_note = _build_context_payload(
+                transcription_log=transcription_log,
+                clipboard_snapshot=clipboard_snapshot,
+            )
+            if context_note:
+                instructions += context_note
+
             # Get model info for logging
-            if provider_cfg.llm_provider == "local":
+            if provider_cfg.llm_provider == "ollama":
                 model_info = f"{provider_cfg.llm_provider}:{ollama_cfg.llm_ollama_model}"
             elif provider_cfg.llm_provider == "openai":
                 model_info = f"{provider_cfg.llm_provider}:{openai_llm_cfg.llm_openai_model}"
@@ -209,7 +349,6 @@ async def _async_main(  # noqa: PLR0912, PLR0915
             else:
                 msg = f"Unsupported LLM provider: {provider_cfg.llm_provider}"
                 raise ValueError(msg)
-
             processed_transcript = await process_and_update_clipboard(
                 system_prompt=SYSTEM_PROMPT,
                 agent_instructions=instructions,
@@ -223,6 +362,7 @@ async def _async_main(  # noqa: PLR0912, PLR0915
                 clipboard=general_cfg.clipboard,
                 quiet=general_cfg.quiet,
                 live=live,
+                context=combined_context,
             )
 
             # Log transcription if requested
@@ -292,6 +432,8 @@ def transcribe(  # noqa: PLR0912
     asr_wyoming_ip: str = opts.ASR_WYOMING_IP,
     asr_wyoming_port: int = opts.ASR_WYOMING_PORT,
     asr_openai_model: str = opts.ASR_OPENAI_MODEL,
+    asr_openai_base_url: str | None = opts.ASR_OPENAI_BASE_URL,
+    asr_openai_prompt: str | None = opts.ASR_OPENAI_PROMPT,
     # --- LLM Configuration ---
     llm_ollama_model: str = opts.LLM_OLLAMA_MODEL,
     llm_ollama_host: str = opts.LLM_OLLAMA_HOST,
@@ -365,7 +507,7 @@ def transcribe(  # noqa: PLR0912
     provider_cfg = config.ProviderSelection(
         asr_provider=asr_provider,
         llm_provider=llm_provider,
-        tts_provider="local",  # Not used in transcribe
+        tts_provider="wyoming",  # Not used in transcribe
     )
     wyoming_asr_cfg = config.WyomingASR(
         asr_wyoming_ip=asr_wyoming_ip,
@@ -374,6 +516,8 @@ def transcribe(  # noqa: PLR0912
     openai_asr_cfg = config.OpenAIASR(
         asr_openai_model=asr_openai_model,
         openai_api_key=openai_api_key,
+        openai_base_url=asr_openai_base_url,
+        asr_openai_prompt=asr_openai_prompt,
     )
     ollama_cfg = config.Ollama(
         llm_ollama_model=llm_ollama_model,
