@@ -13,15 +13,15 @@ async def test_create_llm_agent_with_gemini() -> None:
     """Test that the create_llm_agent function can build an agent with the Gemini provider."""
     provider_cfg = config.ProviderSelection(
         llm_provider="gemini",
-        asr_provider="local",
-        tts_provider="local",
+        asr_provider="wyoming",
+        tts_provider="wyoming",
     )
     gemini_cfg = config.GeminiLLM(
         llm_gemini_model="gemini-1.5-flash",
         gemini_api_key="test-key",
     )
     ollama_cfg = config.Ollama(
-        llm_ollama_model="qwen3:4b",
+        llm_ollama_model="gemma3:4b",
         llm_ollama_host="http://localhost:11434",
     )
     openai_cfg = config.OpenAILLM(
